#
# spec file for package tinyxml2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_version 10
%define lib_package lib%{name}-%{so_version}
Name:           tinyxml2
Version:        10.0.0
Release:        1.1
Summary:        Basic XML parser in C++
License:        Zlib
Group:          Development/Libraries/C and C++
URL:            https://github.com/leethomason/tinyxml2
Source:         https://github.com/leethomason/tinyxml2/archive/%{version}.tar.gz
BuildRequires:  cmake >= 3.15
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
TinyXML is a feature-bounded XML parser in C++ that can be integrated
into other programs.

TinyXML-2 does not parse or use DTDs (Document Type Definitions) or
XSLs (eXtensible Stylesheet Language). There are other parsers (with
different footprints) to do such.

%package -n     %{lib_package}
Summary:        Basic XML parser in C++
License:        Zlib
Group:          System/Libraries

%description -n %{lib_package}
TinyXML is a feature-bounded XML parser in C++ that can be integrated
into other programs.

TinyXML-2 does not parse or use DTDs (Document Type Definitions) or
XSLs (eXtensible Stylesheet Language). There are other parsers (with
different footprints) to do such.

%package        devel
Summary:        Development files for libtinyxml2
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %{lib_package} = %{version}

%description    devel
Contains libraries and header files for
developing applications that use libtinyxml2.

%prep
%autosetup -p1

%build
%cmake
%make_build

%install
%cmake_install
find %{buildroot} -type f -name "*.la" -delete -print
# /usr/lib/cmake is not owned by cmake; avoid any further conflicts
if [ ! -d "%{buildroot}/%{_libdir}/cmake/%{name}" ]; then
mkdir -p %{buildroot}/%{_libdir}/cmake/%{name}
mv %{buildroot}%{_prefix}/lib/cmake/tinyxml2 %{buildroot}/%{_libdir}/cmake/tinyxml2
fi

%check
%make_build test

%ldconfig_scriptlets -n %{lib_package}

%files -n %{lib_package}
%license LICENSE.txt
%doc readme.md
%{_libdir}/libtinyxml2.so.%{so_version}*

%files devel
%license LICENSE.txt
%{_includedir}/tinyxml2.h
%{_libdir}/libtinyxml2.so
%{_libdir}/pkgconfig/tinyxml2.pc
%{_libdir}/cmake/tinyxml2

%changelog
* Tue May  7 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 10
  * Added function XMLNode::ChildElementCount
  * Fix assertion "_elementPool.CurrentAllocs() ==
    _elementPool.Untracked() failed"
* Sat Dec 11 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 9.0.0:
  * fixes for other platforms
* Tue May 25 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 8.1.0:
  * Add support for files larger than ~2GB
  * Updates to hex value partsing
  * XMLPrinter: Fix indentation of first line when called with
    !compactMode
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 8.0.0:
  three years of changes, see https://github.com/leethomason/tinyxml2/compare/6.0.0...8.0.0
  for details
* Thu May  7 2020 pgajdos@suse.com
- %%{_libexecdir} is now /usr/libexec, so do not use it where
  /usr/lib is intended
* Fri Dec 29 2017 jengelh@inai.de
- Remove rhetoric write style from description.
  Expand description on the features/limits of tinyxml.
* Mon Dec 25 2017 p.drouand@gmail.com
- Update to version 6.0.0
  + No changelog available
* Tue Jul 12 2016 mpluskal@suse.com
- Cleanup spec file
  * run spec-cleaner
  * drop not needed dependencies (libtool and doxygen)
  * execute tests during build
  * use pretty name for tarball
* Tue Apr  7 2015 jengelh@inai.de
- Require pkg-config for pkgconfig() symbols to be generated.
- Drop suggestion for non-existant %%name-docs subpackage.
* Mon Apr  6 2015 p.drouand@gmail.com
- Initial release (version 3.0.0)
